@@ -11,17 +11,6 @@ open Zeroinstall
 module Q = Support.Qdom
 module U = Support.Utils
 
-module StringData =
-  struct
-    type t = string
-    let pp = Format.pp_print_string
-    let unused = "unused"
-  end
-
-module Sat = Zeroinstall_solver.Sat.Make(StringData)
-
-open Sat
-
 module EString =
 struct
   type t = string
@@ -262,89 +251,6 @@ let make_solver_test test_elem =
   )
 
 let suite = "solver">::: [
-  "sat_simple">:: (fun () ->
-    let problem = create () in
-
-    let p1 = add_variable problem "p1" in
-    let p2 = add_variable problem "p2" in
-
-    let lib1 = add_variable problem "lib1" in
-    let lib2 = add_variable problem "lib2" in
-
-    let decider () = Some p1 in
-
-    ignore @@ at_most_one problem [p1; p2];
-    ignore @@ at_most_one problem [lib1; lib2];
-
-    at_least_one problem [neg p1; lib1];
-    at_least_one problem [neg p2; lib2];
-
-    match run_solver problem decider with
-    | None -> assert false
-    | Some solution ->
-        assert (solution p1 = true);
-        assert (solution p2 = false);
-
-        assert (solution lib1 = true);
-        assert (solution lib2 = false)
-  );
-
-  "sat_analyse">:: (fun () ->
-    let problem = create () in
-
-    let p1 = add_variable problem "p1" in
-    let p2 = add_variable problem "p2" in
-
-    let lib1 = add_variable problem "lib1" in
-    let lib2 = add_variable problem "lib2" in
-
-    let conf1 = add_variable problem "conf1" in
-
-    let decider () = Some p1 in
-
-    at_least_one problem [p1; p2];
-    ignore @@ at_most_one problem [p1; p2];
-    ignore @@ at_most_one problem [lib1; lib2];
-
-    (* p1 requires lib1 or lib2 *)
-    at_least_one problem [neg p1; lib1; lib2];
-    at_least_one problem [neg p2; lib1];
-
-    (* p1 requires conf1, which conflicts with lib1 and lib2 *)
-    at_least_one problem [neg p1; conf1];
-    at_least_one problem [neg conf1; neg lib1];
-    at_least_one problem [neg conf1; neg lib2];
-
-    (* We try p1 first. That requires (lib1 or lib2) and conf1.
-      conf1 conflicts with lib, causing us to analyse the problem
-      and backtrack. *)
-
-    match run_solver problem decider with
-    | None -> assert false
-    | Some solution ->
-        assert (solution p1 = false);
-        assert (solution p2 = true);
-
-        assert (solution lib1 = true);
-        assert (solution lib2 = false);
-  );
-
-  "sat_at_most">:: (fun () ->
-    let problem = create () in
-
-    let p1 = add_variable problem "p1" in
-    let p2 = add_variable problem "p2" in
-
-    ignore @@ at_most_one problem [neg p1; neg p2];
-
-    let decider () = Some (neg p1) in
-    match run_solver problem decider with
-    | None -> assert false
-    | Some solution ->
-        assert (solution p1 = false);
-        assert (solution p2 = true);
-  );
-
   "feed_provider">:: (fun () ->
     let open Feed_cache in
     let (config, fake_system) = Fake_system.get_fake_config None in
@@ -446,7 +352,7 @@ let suite = "solver">::: [
     config.network_use <- Minimal_network;
 
     let scope_filter = { linux_multi_scope_filter with Scope_filter.
-      languages = Support.Locale.score_langs @@ U.filter_map Support.Locale.parse_lang ["es_ES"; "fr_FR"];
+      languages = Support.Locale.score_langs @@ List.filter_map Support.Locale.parse_lang ["es_ES"; "fr_FR"];
     } in
 
     let test_solve scope_filter =
@@ -567,13 +473,13 @@ let suite = "solver">::: [
     justify
       ("There is no possible selection using http://foo/Binary.xml 3.\n" ^
       "Can't find all required implementations:\n" ^
-      "- http://foo/Binary.xml#source -> 3 (impossible)\n" ^
+      "- http://foo/Binary.xml#source -> v3 (impossible)\n" ^
       "- http://foo/Compiler.xml -> (problem)\n" ^
       "    http://foo/Binary.xml#source 3 requires version ..!1.0, version 1.0..\n" ^
       "    Rejected candidates:\n" ^
-      "      sha1=999 (5): Incompatible with restriction: version ..!1.0\n" ^
-      "      sha1=345 (1.0): Incompatible with restriction: version ..!1.0\n" ^
-      "      sha1=678 (0.1): Incompatible with restriction: version 1.0..")
+      "      v5 (sha1=999): Incompatible with restriction: version ..!1.0\n" ^
+      "      v1.0 (sha1=345): Incompatible with restriction: version ..!1.0\n" ^
+      "      v0.1 (sha1=678): Incompatible with restriction: version 1.0..")
       iface ~source:true (`Remote_feed "http://foo/Source.xml") "impossible";
     justify
       ("http://foo/Compiler.xml 5 is selectable, but using it would produce a less optimal solution overall.\n\n" ^
